@@ -6,8 +6,6 @@ from .common import *
 
 
 INVALID_METADATA = "module metadata invalid"
-DEFAULT_MAX_MODULE_FILE_SIZE = 1024 * 1024 * 10
-
 
 class UnpackerPackageError(Exception):
     """
@@ -26,8 +24,8 @@ class UnpackerPackageError(Exception):
         return "{}, reason: {}".format(super(UnpackerPackageError, self).__str__(), self.reason)
 
 
-def unpack(bundle, max_bundle_size_mb=None):
-    # type: (IO[bytes], Optional[int]) -> Tuple[Dict[str, Any], IO[bytes], Dict[str, IO[bytes]]]
+def unpack(bundle):
+    # type: (IO[bytes]) -> Tuple[Dict[str, Any], IO[bytes], Dict[str, IO[bytes]]]
     """
     Unpacks a bundled module, performs sanity validation on bundle.
     the module metadata, the actual module and bundle deps are returned
@@ -36,7 +34,7 @@ def unpack(bundle, max_bundle_size_mb=None):
     deps_files = dict()
     try:
         with ZipFile(bundle) as zf:
-            _validate_zip_file(zf, max_bundle_size_mb)
+            _validate_zip_file(zf)
             metadata = json.load(zf.open('module.json'))
             module = zf.open(metadata["module_file"])
             _validate_metadata(metadata)
@@ -57,8 +55,8 @@ def unpack(bundle, max_bundle_size_mb=None):
     return metadata, module, deps_files
 
 
-def _validate_zip_file(zip_file, max_bundle_size_mb):
-    # type: (ZipFile, Optional[int]) -> None
+def _validate_zip_file(zip_file):
+    # type: (ZipFile) -> None
     """
     Checks if all entries within the zip file don't
     exceed a certain threshold.
@@ -74,18 +72,6 @@ def _validate_zip_file(zip_file, max_bundle_size_mb):
                                    reason="module zip file should contains exactly two files and deps folder",
                                    error_code="invalid_number_of_files")
 
-    file_size_limit_bytes = max_bundle_size_mb * 1024 * 1024 if max_bundle_size_mb else DEFAULT_MAX_MODULE_FILE_SIZE
-
-    # Check zip content size.
-    for zip_info in infolist:
-        # Size of the compressed/uncompressed data.
-        if not zip_info.filename.startswith("deps/") and zip_info.file_size > file_size_limit_bytes:
-            raise UnpackerPackageError(message="module zip file did not pass sanity validation",
-                                       reason="module file content is too big",
-                                       error_code="module_size_too_big",
-                                       error_details={'module_size': zip_info.compress_size,
-                                                      'max_size': file_size_limit_bytes})
-
 
 def _validate_metadata(metadata):
     # type: (Dict[str, Any]) -> None
@@ -105,11 +91,10 @@ def _validate_metadata(metadata):
                                    reason="Empty module file name",
                                    error_code="module_file_missing")
 
-    if metadata["architecture"] != 'x86_64':
+    if metadata["architecture"] not in {"x86_64", "aarch64"}:
         raise UnpackerPackageError(message=INVALID_METADATA,
                                    reason="Architecture must be 64 bits",
-                                   error_code="module_architecture_not_supported",
-                                   error_details={'expected': 'x86_64'})
+                                   error_code="module_architecture_not_supported")
 
     if not metadata["version"]:
         raise UnpackerPackageError(message=INVALID_METADATA,
